"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFluentBuilder = void 0;
const DynamicJsonfield_1 = require("./components/dynamicComponents/DynamicJsonfield");
const DynamicBooleanField_1 = require("./components/dynamicComponents/DynamicBooleanField");
const DynamicDateField_1 = require("./components/dynamicComponents/DynamicDateField");
const DynamicPredefinedArrayField_1 = require("./components/dynamicComponents/DynamicPredefinedArrayField");
const DynamicTextfield_1 = require("./components/dynamicComponents/DynamicTextfield");
const react_1 = __importDefault(require("react"));
const FluentPropertyLabel_1 = require("./components/list/components/FluentPropertyLabel");
const FluentFormShimmer_1 = require("./components/list/components/FluentFormShimmer");
const fluentUiLabel_1 = require("./components/fluentUiLabel");
const FluentList_1 = __importDefault(require("./components/list/FluentList"));
const formbuilder_1 = require("@wiberg/formbuilder");
const createFluentBuilder = (labelRender) => {
    const id = "internal_fluentbuilder";
    const defaultLabelRender = fluentUiLabel_1.fluentUiLabel;
    const builderLabelRender = labelRender !== null && labelRender !== void 0 ? labelRender : defaultLabelRender;
    const listComponent = () => FluentList_1.default;
    const loadingSpinnerComponent = () => FluentFormShimmer_1.FluentFormShimmer;
    const build = (renderProps, property, schema) => {
        let { item } = renderProps;
        if (item === null)
            throw Error("item is null");
        if (schema == null)
            throw Error("schema is null");
        let info = (0, formbuilder_1.buildPropertyRenderInfo)(renderProps, schema, property);
        let validationMark = (0, formbuilder_1.getValidationMarkForProperty)(renderProps, property);
        const WrapInLabel = (element) => {
            return (react_1.default.createElement("div", { className: "formbuilder-property", key: `propcon-${info.key}` },
                react_1.default.createElement(FluentPropertyLabel_1.FluentPropertyLabel, { key: `${info.key}-labelcontainer`, labelRender: builderLabelRender, propertySchema: schema, hideLabel: info.props.options.hideLabel, parentKey: info.key, validationMark: validationMark }),
                element));
        };
        const propertyType = formbuilder_1.propertyTypes;
        switch (schema.propertyType) {
            case propertyType.string: return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicTextfield_1.DynamicTextfield, Object.assign({}, schema, info.props))) };
            case propertyType.number: return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicTextfield_1.DynamicTextfield, Object.assign({}, schema, info.props))) };
            case propertyType.boolean: return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicBooleanField_1.DynamicBooleanField, Object.assign({}, schema, info.props))) };
            case propertyType.date: return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicDateField_1.DynamicDateField, Object.assign({}, schema, info.props))) };
            case propertyType.json: return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicJsonfield_1.DynamicJsonfield, Object.assign({}, schema, info.props))) };
            case propertyType.predefinedArray: return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicPredefinedArrayField_1.DynamicPredefinedArrayField, Object.assign({}, schema, info.props))) };
            default: return { found: false, element: undefined };
        }
    };
    return { id, build, loadingComponent: loadingSpinnerComponent, listComponent };
};
exports.createFluentBuilder = createFluentBuilder;
//# sourceMappingURL=FluentBuilder.js.map